<?php

// Function to log liveness events directly
function log_liveness_event($drupal_path, $url, $name, $status) {
    $log_dir = $drupal_path . '/sites/default/files';
    $log_file = $log_dir . '/liveness_log.txt';

    if (!file_exists($log_dir)) {
        mkdir($log_dir, 0777, true);
    }

    $log_entry = date('Y-m-d H:i:s') . " - $name is $status\n";
    file_put_contents($log_file, $log_entry, FILE_APPEND);
    chmod($log_file, 0666); // Ensure the file has rw-rw-rw- permissions

    // Log to console
    echo "$name is $status\n";
}

// Function to execute the Drush command
function execute_drush_command($drupal_path, $url, $name) {
    $drush_path = escapeshellcmd("$drupal_path/vendor/drush/drush/drush");
    $command = "$drush_path --root=$drupal_path liveness:check " . escapeshellarg($url) . " " . escapeshellarg($name);
    echo "Running command: $command\n"; // Debug output
    exec($command, $output, $return_var);

    // Debug output
    echo "Return value: $return_var\n";
    echo "Output:\n" . implode("\n", $output) . "\n";

    if ($return_var !== 0) {
        // Drush command failed, fall back to direct HTTP check
        echo "Drush command failed, falling back to direct HTTP check\n";
        $status = check_http_status($url);
        log_liveness_event($drupal_path, $url, $name, $status);
    } else {
        // Check output for status
        foreach ($output as $line) {
            if (strpos($line, 'is down') !== false) {
                log_liveness_event($drupal_path, $url, $name, 'down');
                return;
            }
        }
        log_liveness_event($drupal_path, $url, $name, 'up');
    }
}

// Function to directly check the HTTP status of the URL
function check_http_status($url) {
    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HEADER, true);
    curl_setopt($ch, CURLOPT_NOBODY, true);
    curl_setopt($ch, CURLOPT_TIMEOUT, 10);

    curl_exec($ch);
    $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($http_code == 200) {
        return 'up';
    } else {
        return 'down';
    }
}

// Main script
if ($argc !== 4) {
    echo "Usage: php liveness.php <drupal_path> <url> <name>\n";
    exit(1);
}

$drupal_path = $argv[1];
$url = $argv[2];
$name = $argv[3];

execute_drush_command($drupal_path, $url, $name);

