<?php

namespace Drupal\liveness\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

class LivenessSortForm extends FormBase {

  public function getFormId() {
    return 'liveness_sort_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['sort_by'] = [
      '#type' => 'select',
      '#title' => $this->t('Sort by'),
      '#options' => [
        'timestamp' => $this->t('Timestamp'),
        'name' => $this->t('Environment Name'),
      ],
      '#default_value' => 'timestamp',
    ];

    $form['sort_order'] = [
      '#type' => 'select',
      '#title' => $this->t('Sort order'),
      '#options' => [
        'asc' => $this->t('Ascending'),
        'desc' => $this->t('Descending'),
      ],
      '#default_value' => 'desc',
    ];

    $form['filter_environment'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Filter by Environment'),
      '#default_value' => '',
      '#description' => $this->t('Enter part or all of the environment name to filter the events.'),
    ];

    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Apply'),
      ],
      'clear' => [
        '#type' => 'submit',
        '#value' => $this->t('Clear Log'),
        '#submit' => ['::clearLog'],
      ],
    ];

    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $query = \Drupal::request()->query->all();
    $query['sort_by'] = $form_state->getValue('sort_by');
    $query['sort_order'] = $form_state->getValue('sort_order');
    $query['filter_environment'] = $form_state->getValue('filter_environment');
    $form_state->setRedirect('liveness.events', [], ['query' => $query]);
  }

  public function clearLog(array &$form, FormStateInterface $form_state) {
    $log_file = DRUPAL_ROOT . '/sites/default/files/liveness_log.txt';
    if (file_exists($log_file)) {
      file_put_contents($log_file, '');
      \Drupal::messenger()->addStatus($this->t('Liveness log has been cleared.'));
    }
    $form_state->setRedirect('liveness.events');
  }
}

