<?php

namespace Drupal\liveness\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;

/**
 * Provides a 'LivenessBlock' block.
 *
 * @Block(
 *   id = "liveness_block",
 *   admin_label = @Translation("Liveness Block"),
 * )
 */
class LivenessBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = \Drupal::config('liveness.settings');
    if (!$config->get('enable_liveness_block')) {
      return [];
    }

    $log_file = DRUPAL_ROOT . '/sites/default/files/liveness_log.txt';
    if (!file_exists($log_file)) {
      return [];
    }

    $events = array_reverse(file($log_file));
    $latest_events = [];
    $now = time();
    $display_timeframe = $config->get('display_events_timeframe') ?? 48; // Default to 48 hours

    foreach ($events as $event) {
      preg_match('/(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}) - (.*)/', $event, $matches);
      if (!empty($matches)) {
        $timestamp = strtotime($matches[1]);
        $status = $matches[2];
        if ($now - $timestamp <= $display_timeframe * 3600) { // Convert hours to seconds
          list($environment, $status) = explode(' is ', $status, 2);
          if (!isset($latest_events[$environment]) || $latest_events[$environment]['timestamp'] < $timestamp) {
            $latest_events[$environment] = [
              'timestamp' => $timestamp,
              'event' => $event,
            ];
          }
        }
      }
    }

    // Sort the latest events by timestamp descending
    usort($latest_events, function ($a, $b) {
      return $b['timestamp'] - $a['timestamp'];
    });

    // Get the top 3 latest unique environment events
    $recent_events = array_slice(array_column($latest_events, 'event'), 0, 3);

    if (empty($recent_events)) {
      return [];
    }

    return [
      '#theme' => 'liveness_block',
      '#events' => $recent_events,
      '#cache' => [
        'max-age' => 90, // Cache for maximum 90 seconds.
      ],
    ];
  }
}

